@@ -18,11 +18,11 @@ from typing import Any, Dict, List, NamedTuple, Optional
 
 import distro
 import structlog
-import yaml
 from requests.exceptions import HTTPError
 
+from db_contrib_tool import config
 from db_contrib_tool.plugin import PluginInterface, Subcommand, SubcommandResult
-from db_contrib_tool.setup_repro_env import config, download
+from db_contrib_tool.setup_repro_env import download
 from db_contrib_tool.utils import evergreen_conn, is_windows
 
 SUBCOMMAND = "setup-repro-env"
@@ -69,7 +69,7 @@ def infer_platform(edition=None, version=None):
     if pltf is None:
         raise ValueError(
             "Platform cannot be inferred. Please specify platform explicitly with -p. "
-            f"Available platforms can be found in {config.SETUP_REPRO_ENV_CONFIG}."
+            f"Available platforms can be found in {config.SETUP_REPRO_ENV_CONFIG_FILE}."
         )
     else:
         return pltf
@@ -160,10 +160,6 @@ class SetupReproEnv(Subcommand):
         self.download_python_venv = download_options.download_python_venv
 
         self.evg_api = evergreen_conn.get_evergreen_api(evergreen_config)
-        with open(config.SETUP_REPRO_ENV_CONFIG) as file_handle:
-            raw_yaml = yaml.safe_load(file_handle)
-        self.config = config.SetupReproEnvConfig(raw_yaml)
-
         self.evg_versions_file = evg_versions_file
 
         self._is_windows = is_windows()
@@ -430,7 +426,7 @@ class SetupReproEnv(Subcommand):
         if buildvariant_name not in evg_version.build_variants_map:
             raise ValueError(
                 f"Buildvariant {buildvariant_name} not found in evergreen. "
-                f"Available buildvariants can be found in {config.SETUP_REPRO_ENV_CONFIG}."
+                f"Available buildvariants can be found in {config.SETUP_REPRO_ENV_CONFIG_FILE}."
             )
 
         urls = evergreen_conn.get_compile_artifact_urls(
@@ -498,7 +494,6 @@ class SetupReproEnv(Subcommand):
             return self.variant
 
         return evergreen_conn.get_buildvariant_name(
-            config=self.config,
             edition=self.edition,
             platform=self.platform,
             architecture=self.architecture,
@@ -600,7 +595,7 @@ class SetupReproEnvPlugin(PluginInterface):
             "--platform",
             dest="platform",
             help="Platform to download. "
-            f"Available platforms can be found in {config.SETUP_REPRO_ENV_CONFIG}.",
+            f"Available platforms can be found in {config.SETUP_REPRO_ENV_CONFIG_FILE}.",
         )
         parser.add_argument(
             "-a",
