@@ -7,6 +7,8 @@ import structlog
 from evergreen import RetryingEvergreenApi, Version
 from requests import HTTPError
 
+from db_contrib_tool.config import SETUP_REPRO_ENV_CONFIG
+
 EVERGREEN_HOST = "https://evergreen.mongodb.com"
 EVERGREEN_CONFIG_LOCATIONS = (
     # Common for machines in Evergreen
@@ -71,11 +73,11 @@ def get_evergreen_api(evergreen_config=None):
     raise last_ex
 
 
-def get_buildvariant_name(config, edition, platform, architecture, major_minor_version):
+def get_buildvariant_name(edition, platform, architecture, major_minor_version):
     """Return Evergreen buildvariant name."""
 
     buildvariant_name = ""
-    evergreen_buildvariants = config.evergreen_buildvariants
+    evergreen_buildvariants = SETUP_REPRO_ENV_CONFIG.evergreen_buildvariants
 
     for buildvariant in evergreen_buildvariants:
         if (
@@ -207,18 +209,25 @@ class _MultiversionTasks(object):
 
 
 def _filter_successful_tasks(evg_tasks) -> _MultiversionTasks:
-    compile_task = None
-    archive_symbols_task = None
+    binary_task = None
+    symbols_task = None
     push_task = None
     for evg_task in evg_tasks:
-        # Only set the compile task if there isn't one already, otherwise
-        # newer tasks like "archive_dist_test_debug" take precedence.
-        if evg_task.display_name in ("compile", "archive_dist_test") and compile_task is None:
-            compile_task = evg_task
-        elif evg_task.display_name == "push":
+        if (
+            binary_task is None
+            and evg_task.display_name in SETUP_REPRO_ENV_CONFIG.evergreen_tasks.binary
+        ):
+            binary_task = evg_task
+        if (
+            push_task is None
+            and evg_task.display_name in SETUP_REPRO_ENV_CONFIG.evergreen_tasks.push
+        ):
             push_task = evg_task
-        elif evg_task.display_name == "archive_dist_test_debug":
-            archive_symbols_task = evg_task
-        if compile_task and push_task and archive_symbols_task:
+        if (
+            symbols_task is None
+            and evg_task.display_name in SETUP_REPRO_ENV_CONFIG.evergreen_tasks.symbols
+        ):
+            symbols_task = evg_task
+        if binary_task and push_task and symbols_task:
             break
-    return _MultiversionTasks(symbols=archive_symbols_task, binary=compile_task, push=push_task)
+    return _MultiversionTasks(symbols=symbols_task, binary=binary_task, push=push_task)
